@@ -1,5 +1,4 @@
 /*
-    This file is part of the KDE project
     SPDX-FileCopyrightText: 2007 Matthias Kretz <kretz@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-only
@@ -8,6 +7,7 @@
 #ifndef KCMULTIDIALOG_P_H
 #define KCMULTIDIALOG_P_H
 
+#include "kcmodule.h"
 #include "kcmultidialog.h"
 #include <QList>
 #include <QStringList>
@@ -17,41 +17,36 @@ class KPageWidgetItem;
 
 class KCMultiDialogPrivate
 {
-    Q_DECLARE_PUBLIC(KCMultiDialog)
-protected:
+public:
     KCMultiDialogPrivate(KCMultiDialog *parent)
         : currentModule(nullptr)
-        , q_ptr(parent)
+        , q(parent)
     {
     }
 
-    virtual ~KCMultiDialogPrivate()
-    {
-    }
-
-    KCModuleProxy *currentModule;
+    KCModule *currentModule;
 
     struct CreatedModule {
-        KCModuleProxy *kcm;
+        KCModule *kcm;
         KPageWidgetItem *item;
         QStringList componentNames;
+        bool firstShow = true;
     };
 
     typedef QList<CreatedModule> ModuleList;
     ModuleList modules;
 
-    void _k_slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetItem *previous);
-    virtual void _k_clientChanged();
-    void _k_dialogClosed();
-    void _k_updateHeader(bool use, const QString &message);
+    void slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetItem *previous);
+    void clientChanged();
+    void dialogClosed();
+    void updateHeader(bool use, const QString &message);
 
-    KCMultiDialog *q_ptr;
+    KCMultiDialog *q;
 
-private:
     void init();
     void apply();
-    bool resolveChanges(KCModuleProxy *currentProxy);
-    bool moduleSave(KCModuleProxy *module);
+    bool resolveChanges(KCModule *currentProxy);
+    bool moduleSave(KCModule *module);
 };
 
 #endif // KCMULTIDIALOG_P_H
